==> percona-pgbackrest_2.27.orig.tar.gz: percona-pgbackrest-2.27/src/common/type/stringz.h <==
/***********************************************************************************************************************************
Zero-Terminated String Handler
***********************************************************************************************************************************/
#ifndef COMMON_TYPE_STRINGZ_H
#define COMMON_TYPE_STRINGZ_H

/***********************************************************************************************************************************
Zero-terminated strings that are generally useful
***********************************************************************************************************************************/
#define BRACEL_Z                                                    "{"
#define BRACER_Z                                                    "}"
#define BRACKETL_Z                                                  "["
#define BRACKETR_Z                                                  "]"
#define COLON_Z                                                     ":"
#define COMMA_Z                                                     ","
#define CR_Z                                                        "\r"
#define DASH_Z                                                      "-"
#define DOT_Z                                                       "."
#define DOTDOT_Z                                                    ".."
#define EMPTY_Z                                                     ""
#define EQ_Z                                                        "="
#define FALSE_Z                                                     "false"
#define FSLASH_Z                                                    "/"
#define LF_Z                                                        "\n"
#define N_Z                                                         "n"
#define NULL_Z                                                      "null"
#define QUOTED_Z                                                    "\""
#define TRUE_Z                                                      "true"
#define Y_Z                                                         "y"
#define ZERO_Z                                                      "0"

#endif

==> percona-pgbackrest_2.29.orig.tar.gz: percona-pgbackrest-2.29/src/common/type/stringz.h <==
/***********************************************************************************************************************************
Zero-Terminated String Handler
***********************************************************************************************************************************/
#ifndef COMMON_TYPE_STRINGZ_H
#define COMMON_TYPE_STRINGZ_H

/***********************************************************************************************************************************
Zero-terminated strings that are generally useful
***********************************************************************************************************************************/
#define AMPERSAND_Z                                                 "&"
#define BRACEL_Z                                                    "{"
#define BRACER_Z                                                    "}"
#define BRACKETL_Z                                                  "["
#define BRACKETR_Z                                                  "]"
#define COLON_Z                                                     ":"
#define COMMA_Z                                                     ","
#define CR_Z                                                        "\r"
#define CRLF_Z                                                      "\r\n"
#define DASH_Z                                                      "-"
#define DOT_Z                                                       "."
#define DOTDOT_Z                                                    ".."
#define EMPTY_Z                                                     ""
#define EQ_Z                                                        "="
#define FALSE_Z                                                     "false"
#define FSLASH_Z                                                    "/"
#define LF_Z                                                        "\n"
#define N_Z                                                         "n"
#define NULL_Z                                                      "null"
#define QUESTION_Z                                                  "?"
#define QUOTED_Z                                                    "\""
#define TRUE_Z                                                      "true"
#define Y_Z                                                         "y"
#define ZERO_Z                                                      "0"

#endif
